.. module:: pymeasure.instruments.thorlabs

########
Thorlabs
########

This section contains specific documentation on the Thorlabs instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

.. toctree::
   :maxdepth: 2

   thorlabspm100usb
   thorlabspro8000
